from django.test import TestCase
from web.forms import SubjectAddForm
from web.models import Subject

from web.tests.functions import *

class SubjectAddFormTests(TestCase):
    def setUp(self):
        location = get_test_location()
        self.sample_data = {'first_name': 'name',
            'last_name': 'name',
            'sex' : Subject.SEX_CHOICES_MALE,
            'type' : Subject.SUBJECT_TYPE_CHOICES_CONTROL,
            'default_location' : location.id,
            'screening_number'  : "123",
            'country' : 'Luxembourg'
        }
    def test_validation(self):
        form = SubjectAddForm(data=self.sample_data)
        form.is_valid()
        self.assertTrue(form.is_valid())

    def test_invalid(self):
        form_data = self.sample_data
        form_data['screening_number'] = "123"

        form = SubjectAddForm(data=form_data)
        form.is_valid()
        self.assertTrue(form.is_valid())
        form.save()

        form2 = SubjectAddForm(data=form_data)
        validation_status = form2.is_valid()
        self.assertFalse(validation_status)
        self.assertTrue("screening_number" in form2.errors)

    def test_invalid_2(self):
        form_data = self.sample_data
        form_data['nd_number'] = "123"

        form = SubjectAddForm(data=form_data)
        form.is_valid()
        self.assertTrue(form.is_valid())
        form.save()

        form_data['screening_number'] = "2"
        form2 = SubjectAddForm(data=form_data)
        validation_status = form2.is_valid()
        self.assertFalse(validation_status)
        self.assertTrue("nd_number" in form2.errors)

    def test_invalid_3(self):
        form_data = self.sample_data
        form_data['screening_number'] = ""

        form = SubjectAddForm(data=form_data)
        validation_status = form.is_valid()
        self.assertFalse(validation_status)
        self.assertTrue("screening_number" in form.errors)
