from django.contrib.auth.models import User
from django.test import TestCase, RequestFactory
from django.urls import reverse

from web.views import *
from web.tests.functions import *

class AppointmentsViewTests(TestCase):
    def setUp(self):
        # Every test needs access to the request factory.
        self.factory = RequestFactory()
        self.user = User.objects.create_user(
            username='piotr', email='jacob@bla', password='top_secret')

    def test_appointments_list_request(self):
        request = self.factory.get(reverse('web.views.appointments'));
        request.user = self.user
        response = appointments(request);
        self.assertEqual(response.status_code, 200)

    def test_mark_as_finished(self):
        subject = create_subject();
        visit = create_visit(subject)
        appointment = create_appointment(visit)
        request = self.factory.get(reverse('web.views.appointment_mark', args=[appointment.id, 'finished']));
        request.user = self.user
        response = appointment_mark(request, appointment.id, 'finished');
        self.assertEqual(response.status_code, 302)

    def test_mark_as_cancelled(self):
        subject = create_subject();
        visit = create_visit(subject)
        appointment = create_appointment(visit)
        request = self.factory.get(reverse('web.views.appointment_mark', args=[appointment.id, 'cancelled']));
        request.user = self.user
        response = appointment_mark(request, appointment.id, 'cancelled');
        self.assertEqual(response.status_code, 302)
        update_appointment = Appointment.objects.filter(id= appointment.id)[0]
        self.assertEqual(update_appointment.status, Appointment.APPOINTMENT_STATUS_CANCELLED)

    def test_mark_as_no_show(self):
        subject = create_subject();
        visit = create_visit(subject)
        appointment = create_appointment(visit)
        request = self.factory.get(reverse('web.views.appointment_mark', args=[appointment.id, 'no_show']));
        request.user = self.user
        response = appointment_mark(request, appointment.id, 'no_show');
        self.assertEqual(response.status_code, 302)
        update_appointment = Appointment.objects.filter(id= appointment.id)[0]
        self.assertEqual(update_appointment.status, Appointment.APPOINTMENT_STATUS_NO_SHOW)
